@@ -14,64 +14,6 @@ import yaml
 # Import cloud helper lazily inside functions to avoid heavy deps at module load
 
 
-def _warn_if_gcp_default_sa(force_prompt: bool = False) -> None:
-    """Warn the user when the active gcloud principal is the default VM service
-    account.  See detailed docstring later in file (duplicate for early
-    availability)."""
-
-    from dayhoff_tools.cli import cloud_commands as _cc
-
-    try:
-        impersonation = _cc._get_current_gcp_impersonation()
-        user = _cc._get_current_gcp_user()
-        active = impersonation if impersonation != "None" else user
-        short = _cc._get_short_name(active)
-
-        # Determine if user creds are valid
-        auth_valid = _cc._is_gcp_user_authenticated()
-    except Exception:
-        # If any helper errors out, don't block execution
-        return
-
-    problem_type = None  # "default_sa" | "stale"
-    if short == "default VM service account":
-        problem_type = "default_sa"
-    elif not auth_valid:
-        problem_type = "stale"
-
-    if problem_type is None:
-        return  # Everything looks good
-
-    YELLOW = getattr(_cc, "YELLOW", "\033[0;33m")
-    BLUE = getattr(_cc, "BLUE", "\033[0;36m")
-    RED = getattr(_cc, "RED", "\033[0;31m")
-    NC = getattr(_cc, "NC", "\033[0m")
-
-    if problem_type == "default_sa":
-        msg_body = (
-            f"You are currently authenticated as the *default VM service account*.\n"
-            f"   This will block gsutil/DVC access to private buckets (e.g. warehouse)."
-        )
-    else:  # stale creds
-        msg_body = (
-            f"Your GCP credentials appear to be *expired/stale*.\n"
-            f"   Re-authenticate to refresh the access token."
-        )
-
-    print(
-        f"{YELLOW}⚠  {msg_body}{NC}\n"
-        f"{YELLOW}   Run {BLUE}dh gcp login{YELLOW} or {BLUE}dh gcp use-devcon{YELLOW} before retrying.{NC}",
-        file=sys.stderr,
-    )
-
-    if force_prompt and sys.stdin.isatty() and sys.stdout.isatty():
-        import questionary
-
-        if not questionary.confirm("Proceed anyway?", default=False).ask():
-            print(f"{RED}Aborted due to unsafe GCP credentials.{NC}", file=sys.stderr)
-            raise SystemExit(1)
-
-
 def test_github_actions_locally():
     """Run the script test_pytest_in_github_actions_container.sh.sh."""
     script_path = ".devcontainer/scripts/test_pytest_in_github_actions_container.sh"
@@ -83,163 +25,6 @@ def test_github_actions_locally():
         print(f"Error occurred while running the script: {e}")
 
 
-def get_ancestry(filepath: str) -> None:
-    """Take a .dvc file created from import, and generate an ancestry entry
-    that can be manually copied into other .dvc files."""
-    with open(filepath, "r") as file:
-        assert filepath.endswith(".dvc"), "ERROR: Not a .dvc file"
-        ancestor_content = yaml.safe_load(file)
-
-        error_msg = "Unexpected file structure. Are you sure this is a .dvc file generated from `dvc import`?"
-        assert "deps" in ancestor_content, error_msg
-
-        error_msg = "Please only reference data imported from main branches."
-        assert "rev" not in ancestor_content["deps"][0]["repo"], error_msg
-
-        ancestor_info = {
-            "name": os.path.basename(ancestor_content["outs"][0]["path"]),
-            "file_md5_hash": ancestor_content["outs"][0]["md5"],
-            "size": ancestor_content["outs"][0]["size"],
-            "repo_url": ancestor_content["deps"][0]["repo"]["url"],
-            "repo_path": ancestor_content["deps"][0]["path"],
-            "commit_hash": ancestor_content["deps"][0]["repo"]["rev_lock"],
-        }
-        print()
-        yaml.safe_dump(
-            [ancestor_info], sys.stdout, default_flow_style=False, sort_keys=False
-        )
-
-
-def import_from_warehouse_typer() -> None:
-    """Import a file from warehouse.
-
-    Emits an early warning if the active GCP credentials are the *default VM
-    service account* because this will prevent DVC/gsutil from accessing the
-    warehouse bucket.  The user can abort the command when running
-    interactively.
-    """
-
-    # Early-exit guard for wrong GCP credentials
-    _warn_if_gcp_default_sa(force_prompt=True)
-
-    # Import only when the function is called
-    import questionary
-    from dayhoff_tools.warehouse import import_from_warehouse
-
-    # Check if we're in Lightning Studio
-    if _is_lightning_studio():
-        # Lightning Studio behavior
-        _check_dvc_initialized()
-        _configure_studio_cache()
-
-        # Ensure we're running from repo root using REPO_ROOT env var
-        repo_root = os.environ.get("REPO_ROOT")
-        if not repo_root:
-            raise Exception(
-                "REPO_ROOT environment variable not set. Make sure you're in a repo with an active UV virtual environment."
-            )
-
-        current_dir = os.getcwd()
-        if current_dir != repo_root:
-            raise Exception(
-                f"This command must be run from the repo root. "
-                f"Current directory: {current_dir}, Expected: {repo_root}"
-            )
-    else:
-        # Original devcontainer behavior - ensure execution from root
-        cwd = Path(os.getcwd())
-        if cwd.parent.name != "workspaces" or str(cwd.parent.parent) != cwd.root:
-            raise Exception(
-                f"This command must be executed from the repo's root directory (/workspaces/reponame). Current directory: {cwd}"
-            )
-
-    # Use questionary for prompts instead of typer
-    warehouse_path = questionary.text("Warehouse path:").ask()
-
-    # Provide multiple-choice options for output folder
-    output_folder_choice = questionary.select(
-        "Output folder:",
-        choices=["data/imports", "same_as_warehouse", "Custom path..."],
-    ).ask()
-
-    # If custom path is selected, ask for the path
-    if output_folder_choice == "Custom path...":
-        output_folder = questionary.text("Enter custom output folder:").ask()
-    else:
-        output_folder = output_folder_choice
-
-    branch = questionary.text("Branch (default: main):", default="main").ask()
-
-    final_path = import_from_warehouse(
-        warehouse_path=warehouse_path,
-        output_folder=output_folder,
-        branch=branch,
-    )
-
-
-def add_to_warehouse_typer() -> None:
-    """Add a new data file to warehouse and enrich its generated .dvc file.
-
-    As with *dh wimport*, this command fails when the user is logged in with
-    the default VM service account.  A guard therefore warns the user first
-    and allows them to abort interactively.
-    """
-
-    # Early-exit guard for wrong GCP credentials
-    _warn_if_gcp_default_sa(force_prompt=True)
-
-    # Import only when the function is called
-    import questionary
-    from dayhoff_tools.warehouse import add_to_warehouse
-
-    # Check if we're in Lightning Studio
-    if _is_lightning_studio():
-        # Lightning Studio behavior
-        _check_dvc_initialized()
-        _configure_studio_cache()
-
-        # Ensure we're running from repo root using REPO_ROOT env var
-        repo_root = os.environ.get("REPO_ROOT")
-        if not repo_root:
-            raise Exception(
-                "REPO_ROOT environment variable not set. Make sure you're in a repo with an active UV virtual environment."
-            )
-
-        current_dir = os.getcwd()
-        if current_dir != repo_root:
-            raise Exception(
-                f"This command must be run from the repo root. "
-                f"Current directory: {current_dir}, Expected: {repo_root}"
-            )
-    else:
-        # Original devcontainer behavior - ensure execution from root
-        cwd = Path(os.getcwd())
-        if cwd.parent.name != "workspaces" or str(cwd.parent.parent) != cwd.root:
-            raise Exception(
-                f"This command must be executed from the repo's root directory (/workspaces/reponame). Current directory: {cwd}"
-            )
-
-    # Prompt for the data file path
-    warehouse_path = questionary.text("Data file to be registered:").ask()
-
-    # Prompt for the ancestor .dvc file paths
-    ancestor_dvc_paths = []
-    print("\nEnter the path of all ancestor .dvc files (or hit Enter to finish).")
-    print("These files must be generated by `dvc import` or `dh wimport`.")
-    while True:
-        ancestor_path = questionary.text("Ancestor path: ").ask()
-        if ancestor_path:
-            ancestor_dvc_paths.append(ancestor_path)
-        else:
-            print()
-            break
-
-    dvc_path = add_to_warehouse(
-        warehouse_path=warehouse_path,
-        ancestor_dvc_paths=ancestor_dvc_paths,
-    )
-
-
 def delete_local_branch(branch_name: str, folder_path: str):
     """Delete a local Git branch after fetching with pruning.
 
@@ -684,49 +469,3 @@ def update_dependencies(
     except Exception as e:
         print(f"An unexpected error occurred: {e}")
         sys.exit(1)
-
-
-# ----------------------
-# Lightning Studio Commands
-# ----------------------
-
-
-def _is_lightning_studio() -> bool:
-    """Check if we're running in Lightning Studio environment."""
-    return os.path.exists("/teamspace/studios/this_studio")
-
-
-def _check_dvc_initialized() -> None:
-    """Check if DVC is initialized in the current directory."""
-    if not os.path.exists(".dvc"):
-        raise Exception(
-            "DVC is not initialized in this repository. Run 'dvc init' first."
-        )
-
-
-def _configure_studio_cache() -> None:
-    """Configure DVC to use studio-level cache if not already configured."""
-    studio_cache_dir = "/teamspace/studios/this_studio/.dvc_cache"
-
-    # Create cache directory if it doesn't exist
-    os.makedirs(studio_cache_dir, exist_ok=True)
-
-    # Check current cache configuration
-    try:
-        result = subprocess.run(
-            ["dvc", "cache", "dir"], capture_output=True, text=True, check=True
-        )
-        current_cache = result.stdout.strip()
-
-        if current_cache != studio_cache_dir:
-            print(
-                f"Configuring DVC cache to use studio-level directory: {studio_cache_dir}"
-            )
-            # Use --local flag to save in .dvc/config.local (git-ignored)
-            subprocess.run(
-                ["dvc", "cache", "dir", studio_cache_dir, "--local"], check=True
-            )
-            print("✅ DVC cache configured for Lightning Studio (in .dvc/config.local)")
-    except subprocess.CalledProcessError:
-        # If cache dir command fails, try to set it anyway
-        subprocess.run(["dvc", "cache", "dir", studio_cache_dir, "--local"], check=True)
