@@ -1,11 +1,89 @@
 import os
 import subprocess
+import sys
 from datetime import datetime
 from io import StringIO
 from pathlib import Path
 from zoneinfo import ZoneInfo
 
-from ruamel.yaml import YAML
+# Import cloud helper lazily inside functions to avoid heavy deps at module load
+
+
+def _find_project_root() -> Path | None:
+    """
+    Find the project root by searching upwards from the current directory for
+    a `.git` directory or a `pyproject.toml` file.
+
+    Returns:
+        The path to the project root, or None if not found.
+    """
+    current_dir = Path.cwd().resolve()
+    while current_dir != current_dir.parent:
+        if (current_dir / ".git").is_dir() or (current_dir / "pyproject.toml").is_file():
+            return current_dir
+        current_dir = current_dir.parent
+    # Check the final directory in the hierarchy (e.g., '/')
+    if (current_dir / ".git").is_dir() or (current_dir / "pyproject.toml").is_file():
+        return current_dir
+    return None
+
+
+def _warn_if_gcp_default_sa(force_prompt: bool = False) -> None:
+    """Warn the user when the active gcloud principal is the default VM service
+    account.  See detailed docstring later in file (duplicate for early
+    availability)."""
+
+    from dayhoff_tools.cli import cloud_commands as _cc
+
+    try:
+        impersonation = _cc._get_current_gcp_impersonation()
+        user = _cc._get_current_gcp_user()
+        active = impersonation if impersonation != "None" else user
+        short = _cc._get_short_name(active)
+
+        # Determine if user creds are valid
+        auth_valid = _cc._is_gcp_user_authenticated()
+    except Exception:
+        # If any helper errors out, don't block execution
+        return
+
+    problem_type = None  # "default_sa" | "stale"
+    if short == "default VM service account":
+        problem_type = "default_sa"
+    elif not auth_valid:
+        problem_type = "stale"
+
+    if problem_type is None:
+        return  # Everything looks good
+
+    YELLOW = getattr(_cc, "YELLOW", "\033[0;33m")
+    BLUE = getattr(_cc, "BLUE", "\033[0;36m")
+    RED = getattr(_cc, "RED", "\033[0;31m")
+    NC = getattr(_cc, "NC", "\033[0m")
+
+    if problem_type == "default_sa":
+        msg_body = (
+            f"You are currently authenticated as the *default VM service account*.\n"
+            f"   This will block gsutil/DVC access to private buckets (e.g. warehouse)."
+        )
+    else:  # stale creds
+        msg_body = (
+            f"Your GCP credentials appear to be *expired/stale*.\n"
+            f"   Re-authenticate to refresh the access token."
+        )
+
+    print(
+        f"{YELLOW}⚠  {msg_body}{NC}\n"
+        f"{YELLOW}   Run {BLUE}dh gcp login{YELLOW} or {BLUE}dh gcp use-devcon{YELLOW} before retrying.{NC}",
+        file=sys.stderr,
+    )
+
+    if force_prompt and sys.stdin.isatty() and sys.stdout.isatty():
+        import questionary
+
+        if not questionary.confirm("Proceed anyway?", default=False).ask():
+            print(f"{RED}Aborted due to unsafe GCP credentials.{NC}", file=sys.stderr)
+            raise SystemExit(1)
 
 
 def human_readable_size(size_bytes):
@@ -74,6 +152,8 @@ def format_yaml_with_meta_spacing(yaml_str: str) -> str:
 
 def update_dvc_files(directory):
     """Traverse directory and update .dvc files with human-readable size, preserving existing formatting"""
+    from ruamel.yaml import YAML
+
     yaml = YAML()
     yaml.preserve_quotes = True
     yaml.indent(mapping=2, sequence=4, offset=2)
@@ -188,6 +268,8 @@ def import_from_warehouse(
         subprocess.run(command, check=True)
 
     # Copy meta section from warehouse_path to final_path.dvc
+    from ruamel.yaml import YAML
+
     yaml = YAML()
     yaml.preserve_quotes = True
     yaml.indent(mapping=2, sequence=4, offset=2)
@@ -248,6 +330,8 @@ def add_to_warehouse(
 
     # Process each ancestor .dvc file
     ancestors = []
+    from ruamel.yaml import YAML
+
     yaml_loader = YAML()
     yaml_loader.preserve_quotes = True
     yaml_loader.indent(mapping=2, sequence=4, offset=2)
@@ -282,27 +366,6 @@ def add_to_warehouse(
     # Change the working directory to the warehouse folder
     os.chdir("warehouse")
 
-    # Configure DVC cache for Lightning Studio if needed
-    if os.path.exists("/teamspace/studios/this_studio"):
-        studio_cache_dir = "/teamspace/studios/this_studio/.dvc_cache"
-        os.makedirs(studio_cache_dir, exist_ok=True)
-        try:
-            result = subprocess.run(
-                ["dvc", "cache", "dir"], capture_output=True, text=True, check=True
-            )
-            current_cache = result.stdout.strip()
-            if current_cache != studio_cache_dir:
-                subprocess.run(
-                    ["dvc", "cache", "dir", studio_cache_dir, "--local"], check=True
-                )
-                print(
-                    f"✅ Configured warehouse DVC cache for Lightning Studio: {studio_cache_dir}"
-                )
-        except subprocess.CalledProcessError:
-            subprocess.run(
-                ["dvc", "cache", "dir", studio_cache_dir, "--local"], check=True
-            )
-
     # Add and push the data file
     subprocess.run(["dvc", "add", warehouse_path], check=True)
 
@@ -437,3 +500,184 @@ def get_from_warehouse(
         subprocess.run(command, check=True)
 
     return final_path
+
+
+def get_ancestry(filepath: str) -> None:
+    """Take a .dvc file created from import, and generate an ancestry entry
+    that can be manually copied into other .dvc files."""
+    with open(filepath, "r") as file:
+        assert filepath.endswith(".dvc"), "ERROR: Not a .dvc file"
+        import yaml
+
+        ancestor_content = yaml.safe_load(file)
+
+        error_msg = "Unexpected file structure. Are you sure this is a .dvc file generated from `dvc import`?"
+        assert "deps" in ancestor_content, error_msg
+
+        error_msg = "Please only reference data imported from main branches."
+        assert "rev" not in ancestor_content["deps"][0]["repo"], error_msg
+
+        ancestor_info = {
+            "name": os.path.basename(ancestor_content["outs"][0]["path"]),
+            "file_md5_hash": ancestor_content["outs"][0]["md5"],
+            "size": ancestor_content["outs"][0]["size"],
+            "repo_url": ancestor_content["deps"][0]["repo"]["url"],
+            "repo_path": ancestor_content["deps"][0]["path"],
+            "commit_hash": ancestor_content["deps"][0]["repo"]["rev_lock"],
+        }
+        print()
+        yaml.safe_dump(
+            [ancestor_info], sys.stdout, default_flow_style=False, sort_keys=False
+        )
+
+
+def import_from_warehouse_typer() -> None:
+    """Import a file from warehouse.
+
+    Emits an early warning if the active GCP credentials are the *default VM
+    service account* because this will prevent DVC/gsutil from accessing the
+    warehouse bucket.  The user can abort the command when running
+    interactively.
+    """
+
+    # Early-exit guard for wrong GCP credentials
+    _warn_if_gcp_default_sa(force_prompt=True)
+
+    # Import only when the function is called
+    import questionary
+
+    # Ensure execution from root directory
+    project_root = _find_project_root()
+    cwd = Path.cwd()
+    if not project_root or project_root != cwd:
+        error_msg = (
+            "This command must be run from the project's root directory, which is"
+            " expected to contain a `.git` folder or a `pyproject.toml` file.\n"
+            f"Current directory: {cwd}"
+        )
+        if project_root:
+            error_msg += f"\nDetected project root: {project_root}"
+        raise Exception(error_msg)
+
+    # Use questionary for prompts instead of typer
+    warehouse_path = questionary.text("Warehouse path:").ask()
+
+    # Provide multiple-choice options for output folder
+    output_folder_choice = questionary.select(
+        "Output folder:",
+        choices=["data/imports", "same_as_warehouse", "Custom path..."],
+    ).ask()
+
+    # If custom path is selected, ask for the path
+    if output_folder_choice == "Custom path...":
+        output_folder = questionary.text("Enter custom output folder:").ask()
+    else:
+        output_folder = output_folder_choice
+
+    branch = questionary.text("Branch (default: main):", default="main").ask()
+
+    final_path = import_from_warehouse(
+        warehouse_path=warehouse_path,
+        output_folder=output_folder,
+        branch=branch,
+    )
+
+
+def get_from_warehouse_typer() -> None:
+    """Get a file from warehouse using `dvc get`.
+
+    Emits an early warning if the active GCP credentials are the *default VM
+    service account* because this will prevent DVC/gsutil from accessing the
+    warehouse bucket.  The user can abort the command when running
+    interactively.
+    """
+
+    # Early-exit guard for wrong GCP credentials
+    _warn_if_gcp_default_sa(force_prompt=True)
+
+    # Import only when the function is called
+    import questionary
+
+    # Ensure execution from root directory
+    project_root = _find_project_root()
+    cwd = Path.cwd()
+    if not project_root or project_root != cwd:
+        error_msg = (
+            "This command must be run from the project's root directory, which is"
+            " expected to contain a `.git` folder or a `pyproject.toml` file.\n"
+            f"Current directory: {cwd}"
+        )
+        if project_root:
+            error_msg += f"\nDetected project root: {project_root}"
+        raise Exception(error_msg)
+
+    # Use questionary for prompts instead of typer
+    warehouse_path = questionary.text("Warehouse path:").ask()
+
+    # Provide multiple-choice options for output folder
+    output_folder_choice = questionary.select(
+        "Output folder:",
+        choices=["data/imports", "same_as_warehouse", "Custom path..."],
+    ).ask()
+
+    # If custom path is selected, ask for the path
+    if output_folder_choice == "Custom path...":
+        output_folder = questionary.text("Enter custom output folder:").ask()
+    else:
+        output_folder = output_folder_choice
+
+    branch = questionary.text("Branch (default: main):", default="main").ask()
+
+    final_path = get_from_warehouse(
+        warehouse_path=warehouse_path,
+        output_folder=output_folder,
+        branch=branch,
+    )
+
+
+def add_to_warehouse_typer() -> None:
+    """Add a new data file to warehouse and enrich its generated .dvc file.
+
+    As with *dh wimport*, this command fails when the user is logged in with
+    the default VM service account.  A guard therefore warns the user first
+    and allows them to abort interactively.
+    """
+
+    # Early-exit guard for wrong GCP credentials
+    _warn_if_gcp_default_sa(force_prompt=True)
+
+    # Import only when the function is called
+    import questionary
+
+    # Ensure execution from root directory
+    project_root = _find_project_root()
+    cwd = Path.cwd()
+    if not project_root or project_root != cwd:
+        error_msg = (
+            "This command must be run from the project's root directory, which is"
+            " expected to contain a `.git` folder or a `pyproject.toml` file.\n"
+            f"Current directory: {cwd}"
+        )
+        if project_root:
+            error_msg += f"\nDetected project root: {project_root}"
+        raise Exception(error_msg)
+
+    # Prompt for the data file path
+    warehouse_path = questionary.text("Data file to be registered:").ask()
+
+    # Prompt for the ancestor .dvc file paths
+    ancestor_dvc_paths = []
+    print("\nEnter the path of all ancestor .dvc files (or hit Enter to finish).")
+    print("These files must be generated by `dvc import` or `dh wimport`.")
+    while True:
+        ancestor_path = questionary.text("Ancestor path: ").ask()
+        if ancestor_path:
+            ancestor_dvc_paths.append(ancestor_path)
+        else:
+            print()
+            break
+
+    dvc_path = add_to_warehouse(
+        warehouse_path=warehouse_path,
+        ancestor_dvc_paths=ancestor_dvc_paths,
+    )
